@@ -610,124 +610,3 @@ animate_model <- function(model, file, steps, gif = NULL, width = 800, height =
   else
     gganimate::anim_save(gif, anim)
 }
-
-# helper functions --------------------------------------------------------
-
-# Create a table of population split edges for graph visualization
-get_split_edges <- function(split_table) {
-  split_edges <- split_table[split_table$parent != "__pop_is_ancestor",
-                             c("parent", "pop", "tsplit")]
-  names(split_edges) <- c("from", "to", "time")
-
-  if (!nrow(split_edges)) return(split_edges)
-
-  split_edges$type <- "split"
-  split_edges$rate <- NA
-  split_edges$x <- paste0(split_edges$from, "#####", split_edges$time)
-  split_edges$y <- paste0(split_edges$to, "#####", split_edges$time)
-
-  split_edges <- split_edges[, c("x", "y", "type", "time", "rate")]
-  rownames(split_edges) <- NULL
-
-  split_edges
-}
-
-
-# Create a table of population geneflow edges for graph visualization
-get_geneflow_edges <- function(admix_table) {
-  if (is.null(admix_table)) {
-    admix_edges <- data.frame(matrix(ncol = 4, nrow = 0))
-    colnames(admix_edges) <- c("from", "to", "rate", "tstart")
-    return(admix_edges)
-  }
-
-  admix_edges <- admix_table[, c("from", "to", "rate", "tstart")]
-  names(admix_edges) <- c("from", "to", "rate", "time")
-  admix_edges$type <- "geneflow"
-  admix_edges$rate <- sprintf("%.1f%%", admix_edges$rate * 100)
-  admix_edges$x <- paste0(admix_edges$from, "#####", admix_edges$time)
-  admix_edges$y <- paste0(admix_edges$to, "#####", admix_edges$time)
-
-  admix_edges[, c("x", "y", "type", "time", "rate")]
-}
-
-
-# Create a table of 'intermediate' edges for graph visualization
-#
-# For plotting the entire geneflow graph, just nodes representing population
-# splits are not enough. We also need nodes (population states) which are not
-# explicitly simulated as separate population, but they represent time points
-# needed to plot geneflow edges.
-get_intermediate_edges <- function(split_edges, geneflow_edges) {
-  edges <- rbind(split_edges, geneflow_edges)
-
-  all_nodes <- c(edges$x, edges$y)
-
-  intermediate_nodes <- lapply(
-    unique(gsub("#####.*$", "", all_nodes)),
-    function(i) {
-      # grab all nodes and their times belonging to the current population i
-      nodes <- all_nodes[grepl(paste0(i, "#####"), all_nodes)]
-      times <- gsub(".*#####", "", nodes)
-      # leave out the ancestral node/time from the sorting (in case it is even
-      # present as a node with a non-integer "ancestral" time)
-      ancestor <- nodes[times == "ancestral"]
-      nodes <- nodes[times != "ancestral"]
-      times <- as.integer(times[times != "ancestral"])
-      c(ancestor, unique(nodes[order(times, decreasing = TRUE)]))
-    }
-  )
-
-  lapply(intermediate_nodes, function(nodes) {
-    if (length(nodes) == 1) return(NULL)
-    # construct data frame of consecutive, linked pairs of nodes
-    pairs <- cbind(nodes[-length(nodes)], nodes[-1]) %>%
-      as.data.frame(stringsAsFactors = FALSE) %>%
-      stats::setNames(c("x", "y"))
-    pairs$type <- "intermediate"
-    pairs$time <- as.integer(gsub(".*#####", "", pairs$y))
-    pairs$rate <- NA
-    pairs
-  }) %>%
-  do.call(rbind, .)
-}
-
-
-# Get table of node labels in the graph
-get_graph_nodes <- function(edges) {
-  nodes <- unique(c(edges$x, edges$y))
-
-  # find the first occurrence of a population in the model based
-  # on the time label
-  pops <- gsub("#####.*$", "", nodes)
-  times <- as.integer(gsub("^.*#####", "", nodes))
-
-  ordered <- order(times, decreasing = TRUE)
-
-  # non-duplicated elements in the vector of population names
-  # indicate the first position of such element
-  nodes <- data.frame(
-    name = nodes[ordered],
-    pop = pops[ordered],
-    time = times[ordered],
-    first = !duplicated(pops[ordered]),
-    stringsAsFactors = FALSE
-  )
-  # assign a type to each node based on the corresponding edge type
-  nodes$type <- sapply(nodes$name, function(i) {
-    type <- grep("intermediate", edges[edges$y == i, ]$type, invert = TRUE, value = TRUE)
-    if (length(type) > 0)
-      return(unique(type))
-    else
-      return("intermediate")
-  })
-  nodes$type[!nodes$name %in% edges$y] <- "ancestral"
-
-  nodes <- nodes %>% dplyr::mutate(label = dplyr::case_when(
-    type == "split" ~ sprintf("%s split\nat %s", pop, time),
-    type == "ancestral" ~ paste(pop, "(ancestor)"),
-    type == "geneflow" ~ sprintf("geneflow\nat %s", time),
-    type == "intermediate" ~ sprintf("from %s", pop)
-  ))
-  nodes
-}
